# Frequenz channels Release Notes

## New Features

- Added support for disabling the overflow-warning log messagess in broadcast receivers, through the `warn_on_overflow` parameter on `Broadcast.new_receiver()` calls.
